# setupCLI

A command line application for setting up basic environments for projects

# Installation

## Using Pip
```bash
  $ pip install setupCLI
```

## Manual

```bash
  $ git clone https://github.com/AabhasKrJha/setupCLI
  $ cd setupCLI
  $ python setup.py install
```

# Usage

```bash
$ setupCLI
```

`setupCLI <project name>`

```bash
$ setupCLI 'project X'
```

